==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/KeyVaultKeyReferenceKeyVaultArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The key vault reference.
 * @property id The resource id.
 */
public data class KeyVaultKeyReferenceKeyVaultArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs =
        com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultKeyReferenceKeyVaultArgs].
 */
@PulumiTagMarker
public class KeyVaultKeyReferenceKeyVaultArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The resource id.
     */
    @JvmName("ymldjiekjmhesccj")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The resource id.
     */
    @JvmName("uiheojdgfphuluny")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): KeyVaultKeyReferenceKeyVaultArgs = KeyVaultKeyReferenceKeyVaultArgs(
        id = id,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/KeyVaultKeyReferenceKeyVaultArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The key vault reference.
 * @property id The resource id.
 */
public data class KeyVaultKeyReferenceKeyVaultArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs =
        com.pulumi.azurenative.logic.inputs.KeyVaultKeyReferenceKeyVaultArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KeyVaultKeyReferenceKeyVaultArgs].
 */
@PulumiTagMarker
public class KeyVaultKeyReferenceKeyVaultArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The resource id.
     */
    @JvmName("ptsxhqojsivqxppw")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The resource id.
     */
    @JvmName("ulnfcwgxjcoxekju")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): KeyVaultKeyReferenceKeyVaultArgs = KeyVaultKeyReferenceKeyVaultArgs(
        id = id,
    )
}
